@@ -14,7 +14,7 @@ except ImportError:
     import libsvg
     import libmd
 
-__version__ = 'v1.1.9'
+__version__ = 'v1.2.0'
 
 class TranslateJson(object):
     def __init__(self, js_file, link_path, dir_type, output_md, output_gitbook):
@@ -471,7 +471,7 @@ class TranslateJson(object):
                         fd.write("   ")
                 with open(summary, 'w') as fd:
                     fd.write('# Summary \n\n')
-                    fd.write('* [' + file_msg + '寄存器列表](all_register.md)\n')
+                    fd.write('* [寄存器列表](all_register.md)\n')
                     for i in self.js_dpath:
                         self.path_addr_dict[i] = self.get_addr(i)
                     self.max_len = len(self.path_addr_dict[self.js_dpath[-1]][2:])
@@ -483,7 +483,7 @@ class TranslateJson(object):
                             fd.write('  * [' + name + ']('+ name + '.md)\n')
                             self.create_md3(self.js_dpath[i], lm)
                     with open(os.path.join(self.gitbookpath, 'all_register.md'), 'w') as fc:
-                        fc.write("## " + file_msg + "寄存器列表\n\n" + self.all_reg_data)
+                        fc.write("## 寄存器列表\n\n" + self.all_reg_data)
                 print("\n\tcreate " + self.gitbookpath +" success") 
             elif self.dir_type == "link":
                 self.gitbookpath = os.path.join(self.link_path, "_json_output/", file_msg)
@@ -499,7 +499,7 @@ class TranslateJson(object):
                     fd.write('# Summary \n\n')
                     reg_list_path = os.path.join(path_msg, "all_register.md") 
                     reg_detail_path = os.path.join(path_msg, "detail.md") 
-                    fd.write('* [' + file_msg + '寄存器列表](' + reg_list_path + ')\n')
+                    fd.write('* [寄存器列表](' + reg_list_path + ')\n')
                     fd.write('* [寄存器](' + reg_detail_path + ')\n')
                     for i in self.js_dpath:
                         self.path_addr_dict[i] = self.get_addr(i)
@@ -515,9 +515,9 @@ class TranslateJson(object):
                     self.relist(self.all_reg_list)
                     self.create_all_reg_data(lm)
                     with open(os.path.join(self.gitbookpath, 'all_register.md'), 'w') as fc:
-                        fc.write("## " + file_msg + "寄存器列表\n\n" + self.all_reg_data)
+                        fc.write("## 寄存器列表\n\n" + self.all_reg_data)
                     with open(os.path.join(self.gitbookpath, 'all_register_tex.md'), 'w') as fc:
-                        fc.write("## " + file_msg + "寄存器列表\n\n" + self.all_reg_tex_data)
+                        fc.write("## 寄存器列表\n\n" + self.all_reg_tex_data)
                     with open(os.path.join(self.gitbookpath, 'detail.md'), 'w') as fc:
                         fc.write(self.reg_data)
                     with open(os.path.join(self.gitbookpath, 'detail.rst'), 'w') as fc:
@@ -537,7 +537,7 @@ class TranslateJson(object):
             for i in self.js_dpath:
                 self.create_md3(i, lm)
             self.data = "# 寄存器列表\n" + self.all_reg_data + "\n"\
-                    + "# 寄存器详情\n" + self.data.replace("#", "##")
+                    + "# 寄存器详细说明\n" + self.data.replace("#", "##")
             with open(md_file, 'w') as fd:
                 fd.write(self.data)
             print("\n\tcreate " + md_file + " success") 
